import db from '../db.js';
import fs from 'fs/promises';
import config from '../config.js';
import { createHash } from 'crypto';

function base64ToArrayBuffer(base64) {
    var binaryString = atob(base64);
    var bytes = new Uint8Array(binaryString.length);
    for (var i = 0; i < binaryString.length; i++) {
        bytes[i] = binaryString.charCodeAt(i);
    }
    return bytes.buffer;
}

class CaptchaService {
    async new(image, solution, submitter) {
        const b64 = image.replace(/^data:image\/jpeg;base64,/, "");
        const arrayBuffer = base64ToArrayBuffer(b64);
        const buffer = Buffer.from(arrayBuffer);
        const hash = createHash('md5').update(buffer).digest('hex');
        await fs.writeFile(`${config.data_dir}/${hash}.jpeg`, b64, 'base64');
        await db.query("INSERT INTO captchas (hash, solution, submitter) VALUES ($1, $2, $3)", [hash, solution, submitter]);
    }
}

export default new CaptchaService();